@@ -54,34 +54,6 @@ progress_t poll_mirror_progress(struct cmd_context *cmd,
 	return PROGRESS_FINISHED_SEGMENT;
 }
 
-struct volume_group *poll_get_copy_vg(struct cmd_context *cmd,
-				      const char *name,
-				      const char *uuid __attribute__((unused)),
-				      uint32_t flags)
-{
-	dev_close_all();
-
-	if (name && !strchr(name, '/'))
-		return vg_read(cmd, name, NULL, flags);
-
-	/* 'name' is the full LV name; must extract_vgname() */
-	return vg_read(cmd, extract_vgname(cmd, name), NULL, flags);
-}
-
-struct logical_volume *poll_get_copy_lv(struct cmd_context *cmd __attribute__((unused)),
-					struct volume_group *vg,
-					const char *name,
-					const char *uuid,
-					uint64_t lv_type)
-{
-	struct logical_volume *lv = find_lv(vg, name);
-
-	if (!lv || (uuid && strcmp(uuid, (char *)&lv->lvid)) || (lv_type && !(lv->status & lv_type)))
-		return NULL;
-
-	return lv;
-}
-
 static int _check_lv_status(struct cmd_context *cmd,
 			    struct volume_group *vg,
 			    struct logical_volume *lv,
@@ -153,6 +125,7 @@ static void _nanosleep(unsigned secs, unsigned allow_zero_time)
 static void _sleep_and_rescan_devices(struct daemon_parms *parms)
 {
 	if (parms->interval && !parms->aborting) {
+		dev_close_all();
 		_nanosleep(parms->interval, 1);
 		/* Devices might have changed while we slept */
 		init_full_scan_done(0);
@@ -172,7 +145,7 @@ int wait_for_single_lv(struct cmd_context *cmd, struct poll_operation_id *id,
 			_sleep_and_rescan_devices(parms);
 
 		/* Locks the (possibly renamed) VG again */
-		vg = parms->poll_fns->get_copy_vg(cmd, id->vg_name, NULL, READ_FOR_UPDATE);
+		vg = vg_read(cmd, id->vg_name, NULL, READ_FOR_UPDATE);
 		if (vg_read_error(vg)) {
 			release_vg(vg);
 			log_error("ABORTING: Can't reread VG for %s.", id->display_name);
@@ -180,20 +153,23 @@ int wait_for_single_lv(struct cmd_context *cmd, struct poll_operation_id *id,
 			return 0;
 		}
 
-		lv = parms->poll_fns->get_copy_lv(cmd, vg, id->lv_name, id->uuid, parms->lv_type);
+		lv = find_lv(vg, id->lv_name);
 
-		if (!lv && parms->lv_type == PVMOVE) {
-			log_print_unless_silent("%s: No pvmove in progress - already finished or aborted.",
-						id->display_name);
-			unlock_and_release_vg(cmd, vg, vg->name);
-			return 1;
-		}
+		if (lv && id->uuid && strcmp(id->uuid, (char *)&lv->lvid))
+			lv = NULL;
+		if (lv && parms->lv_type && !(lv->status & parms->lv_type))
+			lv = NULL;
 
 		if (!lv) {
-			log_error("ABORTING: Can't find LV in %s for %s.",
-				  vg->name, id->display_name);
+			if (parms->lv_type == PVMOVE)
+				log_print_unless_silent("%s: No pvmove in progress - already finished or aborted.",
+							id->display_name);
+			else
+				log_print_unless_silent("Can't find LV in %s for %s.",
+							vg->name, id->display_name);
+
 			unlock_and_release_vg(cmd, vg, vg->name);
-			return 0;
+			return 1;
 		}
 
 		/*
@@ -340,8 +316,13 @@ static int _poll_vg(struct cmd_context *cmd, const char *vgname,
 
 	/* perform the poll operation on LVs collected in previous cycle */
 	dm_list_iterate_items(idl, &idls) {
-		lv = parms->poll_fns->get_copy_lv(cmd, vg, idl->id->lv_name, idl->id->uuid, parms->lv_type);
-		if (lv && _check_lv_status(cmd, vg, lv, idl->id->display_name, parms, &finished) && !finished)
+		if (!(lv = find_lv(vg, idl->id->lv_name)))
+			continue;
+		if (idl->id->uuid && strcmp(idl->id->uuid, (char *)&lv->lvid))
+			continue;
+		if (parms->lv_type && !(lv->status & parms->lv_type))
+			continue;
+		if (_check_lv_status(cmd, vg, lv, idl->id->display_name, parms, &finished) && !finished)
 			parms->outstanding_count++;
 	}
 
@@ -362,6 +343,8 @@ static void _poll_for_all_vgs(struct cmd_context *cmd,
 		process_each_vg(cmd, 0, NULL, READ_FOR_UPDATE, handle, _poll_vg);
 		if (!parms->outstanding_count)
 			break;
+		if (parms->interval)
+			dev_close_all();
 		_nanosleep(parms->interval, 1);
 	}
 }
@@ -378,32 +361,33 @@ static int report_progress(struct cmd_context *cmd, struct poll_operation_id *id
 	struct volume_group *vg;
 	struct logical_volume *lv;
 
-	vg = parms->poll_fns->get_copy_vg(cmd, id->vg_name, NULL, 0);
+	vg = vg_read(cmd, id->vg_name, NULL, 0);
 	if (vg_read_error(vg)) {
 		release_vg(vg);
 		log_error("Can't reread VG for %s", id->display_name);
 		return 0;
 	}
 
-	lv = parms->poll_fns->get_copy_lv(cmd, vg, id->lv_name, id->uuid, parms->lv_type);
-	if (!lv && parms->lv_type == PVMOVE) {
-		log_print_unless_silent("%s: No pvmove in progress - already finished or aborted.",
-					id->display_name);
-		unlock_and_release_vg(cmd, vg, vg->name);
-		return 1;
-	}
+	lv = find_lv(vg, id->lv_name);
+
+	if (lv && id->uuid && strcmp(id->uuid, (char *)&lv->lvid))
+		lv = NULL;
+	if (lv && parms->lv_type && !(lv->status & parms->lv_type))
+		lv = NULL;
 
 	if (!lv) {
-		log_warn("Can't find LV in %s for %s. Already finished or removed.",
-			  vg->name, id->display_name);
-		unlock_and_release_vg(cmd, vg, vg->name);
-		return 1;
+		if (parms->lv_type == PVMOVE)
+			log_verbose("%s: No pvmove in progress - already finished or aborted.",
+				    id->display_name);
+		else
+			log_verbose("Can't find LV in %s for %s. Already finished or removed.",
+				    vg->name, id->display_name);
+		goto out;
 	}
 
 	if (!lv_is_active_locally(lv)) {
-		log_print_unless_silent("%s: Interrupted: No longer active.", id->display_name);
-		unlock_and_release_vg(cmd, vg, vg->name);
-		return 1;
+		log_verbose("%s: Interrupted: No longer active.", id->display_name);
+		goto out;
 	}
 
 	if (parms->poll_fns->poll_progress(cmd, lv, id->display_name, parms) == PROGRESS_CHECK_FAILED) {
@@ -411,6 +395,7 @@ static int report_progress(struct cmd_context *cmd, struct poll_operation_id *id
 		return_0;
 	}
 
+out:
 	unlock_and_release_vg(cmd, vg, vg->name);
 
 	return 1;
@@ -487,6 +472,9 @@ static void _lvmpolld_poll_for_all_vgs(struct cmd_context *cmd,
 				report_progress(cmd, idl->id, lpdp.parms);
 		}
 
+		if (lpdp.parms->interval)
+			dev_close_all();
+
 		_nanosleep(lpdp.parms->interval, 0);
 	}
 
@@ -513,6 +501,9 @@ static int _lvmpoll_daemon(struct cmd_context *cmd, struct poll_operation_id *id
 				    (!parms->aborting && !(r = report_progress(cmd, id, parms))))
 					break;
 
+				if (parms->interval)
+					dev_close_all();
+
 				_nanosleep(parms->interval, 0);
 			}
 		}
